@@ -18,7 +18,7 @@ class OptionParser(OptParser):
         self.add_option('--deluge-ratio', dest='deluge_ratio', help='Checks Deluge for completed and that the file has at least reached X share ratio.')
         self.add_option('-d', '--dry-run', dest='dry', action='store_true', help='Dry run your renaming.')
         self.add_option('-e', '--episode', dest='episode', help='Set the episode number. Currently this will cause errors when working with more than one file.')
-        self.add_option('--ignore-filelist', dest='ignore_filelist', help=SUPPRESS_HELP)
+        self.add_option('--ignore-filelist', dest='ignore_filelist', default=(), help=SUPPRESS_HELP)
         self.add_option('--ignore-recursive', action='store_true', dest='ignore_recursive', help='Only use files from the root of a given directory, not entering any sub-directories.')
         self.add_option('--log-file', dest='log_file', help='Set the log file location.')
         self.add_option('-l', '--log-level', dest='log_level', help='Set the log level. Options: short, minimal, info and debug.')
